==> swi-prolog_8.2.4+dfsg.orig.tar.gz: swipl-8.2.4+dfsg/packages/ssl/config.h.cmake <==
#cmakedefine AC_APPLE_UNIVERSAL_BUILD @AC_APPLE_UNIVERSAL_BUILD@
#cmakedefine CRAY_STACKSEG_END @CRAY_STACKSEG_END@
#cmakedefine C_ALLOCA @C_ALLOCA@
#cmakedefine GET0SIG_CONST_T @GET0SIG_CONST_T@
#cmakedefine HAVE_ALLOCA @HAVE_ALLOCA@
#cmakedefine HAVE_ALLOCA_H @HAVE_ALLOCA_H@
#cmakedefine HAVE_CRYPTO_THREADID @HAVE_CRYPTO_THREADID@
#cmakedefine HAVE_CRYPTO_THREADID_GET_CALLBACK @HAVE_CRYPTO_THREADID_GET_CALLBACK@
#cmakedefine HAVE_CRYPTO_THREADID_SET_CALLBACK @HAVE_CRYPTO_THREADID_SET_CALLBACK@
#cmakedefine HAVE_ERR_REMOVE_STATE @HAVE_ERR_REMOVE_STATE@
#cmakedefine HAVE_ERR_REMOVE_THREAD_STATE @HAVE_ERR_REMOVE_THREAD_STATE@
#cmakedefine HAVE_EVP_BLAKE2B512 @HAVE_EVP_BLAKE2B512@
#cmakedefine HAVE_EVP_BLAKE2S256 @HAVE_EVP_BLAKE2S256@
#cmakedefine HAVE_EVP_CIPHER_CTX_RESET @HAVE_EVP_CIPHER_CTX_RESET@
#cmakedefine HAVE_EVP_MD_CTX_FREE @HAVE_EVP_MD_CTX_FREE@
#cmakedefine HAVE_EVP_SHA3_224 @HAVE_EVP_SHA3_224@
#cmakedefine HAVE_EVP_SHA3_256 @HAVE_EVP_SHA3_256@
#cmakedefine HAVE_EVP_SHA3_384 @HAVE_EVP_SHA3_384@
#cmakedefine HAVE_EVP_SHA3_512 @HAVE_EVP_SHA3_512@
#cmakedefine HAVE_FCNTL_H @HAVE_FCNTL_H@
#cmakedefine HAVE_HMAC_CTX_FREE @HAVE_HMAC_CTX_FREE@
#cmakedefine HAVE_HMAC_CTX_NEW @HAVE_HMAC_CTX_NEW@
#cmakedefine HAVE_H_ERRNO @HAVE_H_ERRNO@
#cmakedefine HAVE_I2D_RE_X509_TBS @HAVE_I2D_RE_X509_TBS@
#cmakedefine HAVE_INTTYPES_H @HAVE_INTTYPES_H@
#cmakedefine HAVE_KSECCLASS @HAVE_KSECCLASS@
#cmakedefine HAVE_LIBCRYPT32 @HAVE_LIBCRYPT32@
#cmakedefine HAVE_LIBCRYPTO @HAVE_LIBCRYPTO@
#cmakedefine HAVE_LIBGDI32 @HAVE_LIBGDI32@
#cmakedefine HAVE_LIBPTHREAD @HAVE_LIBPTHREAD@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@
#cmakedefine HAVE_LIBPTHREADGC2 @HAVE_LIBPTHREADGC2@
#cmakedefine HAVE_LIBSSL @HAVE_LIBSSL@
#cmakedefine HAVE_LIBWS2_32 @HAVE_LIBWS2_32@
#cmakedefine HAVE_MEMORY_H @HAVE_MEMORY_H@
#cmakedefine HAVE_OPENSSL_INIT_SSL @HAVE_OPENSSL_INIT_SSL@
#cmakedefine HAVE_OPENSSL_KDF_H @HAVE_OPENSSL_KDF_H@
#cmakedefine HAVE_OPENSSL_SSL_H @HAVE_OPENSSL_SSL_H@
#cmakedefine HAVE_OPENSSL_VERSION @HAVE_OPENSSL_VERSION@
#cmakedefine HAVE_OPENSSL_ZALLOC @HAVE_OPENSSL_ZALLOC@
#cmakedefine HAVE_SECURITY_SECURITY_H @HAVE_SECURITY_SECURITY_H@
#cmakedefine HAVE_SOCKLEN_T @HAVE_SOCKLEN_T@
#cmakedefine HAVE_SSL_CTX_SET_ALPN_PROTOS @HAVE_SSL_CTX_SET_ALPN_PROTOS@
#cmakedefine HAVE_SSL_LIBRARY_INIT @HAVE_SSL_LIBRARY_INIT@
#cmakedefine HAVE_STDINT_H @HAVE_STDINT_H@
#cmakedefine HAVE_STDLIB_H @HAVE_STDLIB_H@
#cmakedefine HAVE_STRINGS_H @HAVE_STRINGS_H@
#cmakedefine HAVE_STRING_H @HAVE_STRING_H@
#cmakedefine HAVE_SYS_SELECT_H @HAVE_SYS_SELECT_H@
#cmakedefine HAVE_SYS_STAT_H @HAVE_SYS_STAT_H@
#cmakedefine HAVE_SYS_TIME_H @HAVE_SYS_TIME_H@
#cmakedefine HAVE_SYS_TYPES_H @HAVE_SYS_TYPES_H@
#cmakedefine HAVE_TIMEGM @HAVE_TIMEGM@
#cmakedefine HAVE_UNISTD_H @HAVE_UNISTD_H@
#cmakedefine HAVE_X509_CHECK_HOST @HAVE_X509_CHECK_HOST@
#cmakedefine HAVE_X509_CRL_DIGEST @HAVE_X509_CRL_DIGEST@
#cmakedefine HAVE_X509_CRL_GET0_SIGNATURE @HAVE_X509_CRL_GET0_SIGNATURE@
#cmakedefine HAVE_X509_DIGEST @HAVE_X509_DIGEST@
#cmakedefine HAVE_X509_GET0_NOTAFTER @HAVE_X509_GET0_NOTAFTER@
#cmakedefine HAVE_X509_GET0_NOTBEFORE @HAVE_X509_GET0_NOTBEFORE@
#cmakedefine HAVE_X509_GET0_SIGNATURE @HAVE_X509_GET0_SIGNATURE@
#cmakedefine HAVE_X509_STORE_CTX_GET0_CHAIN @HAVE_X509_STORE_CTX_GET0_CHAIN@
#cmakedefine HAVE_X509_VERIFY_PARAM_ID @HAVE_X509_VERIFY_PARAM_ID@
#cmakedefine O_PLMT @O_PLMT@
#cmakedefine PACKAGE_BUGREPORT @PACKAGE_BUGREPORT@
#cmakedefine PACKAGE_NAME @PACKAGE_NAME@
#cmakedefine PACKAGE_STRING @PACKAGE_STRING@
#cmakedefine PACKAGE_TARNAME @PACKAGE_TARNAME@
#cmakedefine PACKAGE_URL @PACKAGE_URL@
#cmakedefine PACKAGE_VERSION @PACKAGE_VERSION@
#cmakedefine STACK_DIRECTION @STACK_DIRECTION@
#cmakedefine STDC_HEADERS @STDC_HEADERS@
#cmakedefine SYSTEM_CACERT_FILENAME "@SYSTEM_CACERT_FILENAME@"
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@
#cmakedefine _REENTRANT @_REENTRANT@
#cmakedefine size_t @size_t@

==> swi-prolog_9.0.4+dfsg.orig.tar.gz: swipl-9.0.4+dfsg/packages/ssl/config.h.cmake <==
#cmakedefine AC_APPLE_UNIVERSAL_BUILD @AC_APPLE_UNIVERSAL_BUILD@
#cmakedefine CRAY_STACKSEG_END @CRAY_STACKSEG_END@
#cmakedefine C_ALLOCA @C_ALLOCA@
#cmakedefine GET0SIG_CONST_T @GET0SIG_CONST_T@
#cmakedefine HAVE_ALLOCA @HAVE_ALLOCA@
#cmakedefine HAVE_ALLOCA_H @HAVE_ALLOCA_H@
#cmakedefine HAVE_BN_CHECK_PRIME @HAVE_BN_CHECK_PRIME@
#cmakedefine HAVE_CRYPTO_THREADID @HAVE_CRYPTO_THREADID@
#cmakedefine HAVE_CRYPTO_THREADID_GET_CALLBACK @HAVE_CRYPTO_THREADID_GET_CALLBACK@
#cmakedefine HAVE_CRYPTO_THREADID_SET_CALLBACK @HAVE_CRYPTO_THREADID_SET_CALLBACK@
#cmakedefine HAVE_ERR_REMOVE_STATE @HAVE_ERR_REMOVE_STATE@
#cmakedefine HAVE_ERR_REMOVE_THREAD_STATE @HAVE_ERR_REMOVE_THREAD_STATE@
#cmakedefine HAVE_EVP_BLAKE2B512 @HAVE_EVP_BLAKE2B512@
#cmakedefine HAVE_EVP_BLAKE2S256 @HAVE_EVP_BLAKE2S256@
#cmakedefine HAVE_EVP_CIPHER_CTX_RESET @HAVE_EVP_CIPHER_CTX_RESET@
#cmakedefine HAVE_EVP_PKEY_Q_KEYGEN @HAVE_EVP_PKEY_Q_KEYGEN@
#cmakedefine HAVE_EVP_MAC_FETCH @HAVE_EVP_MAC_FETCH@
#cmakedefine HAVE_EVP_MAC_CTX_FREE @HAVE_EVP_MAC_CTX_FREE@
#cmakedefine HAVE_EVP_MAC_UPDATE @HAVE_EVP_MAC_UPDATE@
#cmakedefine HAVE_EVP_MAC_FINAL @HAVE_EVP_MAC_FINAL@
#cmakedefine HAVE_EVP_MD_CTX_FREE @HAVE_EVP_MD_CTX_FREE@
#cmakedefine HAVE_EVP_PKEY_DECRYPT @HAVE_EVP_PKEY_DECRYPT@
#cmakedefine HAVE_EVP_PKEY_ENCRYPT @HAVE_EVP_PKEY_ENCRYPT@
#cmakedefine HAVE_EVP_PKEY_FREE @HAVE_EVP_PKEY_FREE@
#cmakedefine HAVE_EVP_PKEY_GET_BN_PARAM @HAVE_EVP_PKEY_GET_BN_PARAM@
#cmakedefine HAVE_EVP_PKEY_GET_OCTET_STRING_PARAM @HAVE_EVP_PKEY_GET_OCTET_STRING_PARAM@
#cmakedefine HAVE_EVP_PKEY_GET_SIZE @HAVE_EVP_PKEY_GET_SIZE@
#cmakedefine HAVE_EVP_PKEY_NEW @HAVE_EVP_PKEY_NEW@
#cmakedefine HAVE_EVP_PKEY_SIGN @HAVE_EVP_PKEY_SIGN@
#cmakedefine HAVE_EVP_PKEY_VERIFY @HAVE_EVP_PKEY_VERIFY@
#cmakedefine HAVE_EVP_SHA3_224 @HAVE_EVP_SHA3_224@
#cmakedefine HAVE_EVP_SHA3_256 @HAVE_EVP_SHA3_256@
#cmakedefine HAVE_EVP_SHA3_384 @HAVE_EVP_SHA3_384@
#cmakedefine HAVE_EVP_SHA3_512 @HAVE_EVP_SHA3_512@
#cmakedefine HAVE_FCNTL_H @HAVE_FCNTL_H@
#cmakedefine HAVE_HMAC_CTX_FREE @HAVE_HMAC_CTX_FREE@
#cmakedefine HAVE_HMAC_CTX_NEW @HAVE_HMAC_CTX_NEW@
#cmakedefine HAVE_H_ERRNO @HAVE_H_ERRNO@
#cmakedefine HAVE_I2D_RE_X509_TBS @HAVE_I2D_RE_X509_TBS@
#cmakedefine HAVE_INTTYPES_H @HAVE_INTTYPES_H@
#cmakedefine HAVE_KSECCLASS @HAVE_KSECCLASS@
#cmakedefine HAVE_LIBCRYPT32 @HAVE_LIBCRYPT32@
#cmakedefine HAVE_LIBCRYPTO @HAVE_LIBCRYPTO@
#cmakedefine HAVE_LIBGDI32 @HAVE_LIBGDI32@
#cmakedefine HAVE_LIBPTHREAD @HAVE_LIBPTHREAD@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@
#cmakedefine HAVE_LIBPTHREADGC2 @HAVE_LIBPTHREADGC2@
#cmakedefine HAVE_LIBSSL @HAVE_LIBSSL@
#cmakedefine HAVE_LIBWS2_32 @HAVE_LIBWS2_32@
#cmakedefine HAVE_MEMORY_H @HAVE_MEMORY_H@
#cmakedefine HAVE_OPENSSL_INIT_SSL @HAVE_OPENSSL_INIT_SSL@
#cmakedefine HAVE_OPENSSL_CORE_NAMES_H @HAVE_OPENSSL_CORE_NAMES_H@
#cmakedefine HAVE_OPENSSL_KDF_H @HAVE_OPENSSL_KDF_H@
#cmakedefine HAVE_OPENSSL_PARAM_BUILD_H @HAVE_OPENSSL_PARAM_BUILD_H@
#cmakedefine HAVE_OPENSSL_SSL_H @HAVE_OPENSSL_SSL_H@
#cmakedefine HAVE_OPENSSL_VERSION @HAVE_OPENSSL_VERSION@
#cmakedefine HAVE_OPENSSL_ZALLOC @HAVE_OPENSSL_ZALLOC@
#cmakedefine HAVE_OSSL_PARAM_BLD_NEW @HAVE_OSSL_PARAM_BLD_NEW@
#cmakedefine HAVE_OSSL_PARAM_CONSTRUCT_UTF8_STRING @HAVE_OSSL_PARAM_CONSTRUCT_UTF8_STRING@
#cmakedefine HAVE_SECURITY_SECURITY_H @HAVE_SECURITY_SECURITY_H@
#cmakedefine HAVE_SOCKLEN_T @HAVE_SOCKLEN_T@
#cmakedefine HAVE_SSL_CTX_SET_ALPN_PROTOS @HAVE_SSL_CTX_SET_ALPN_PROTOS@
#cmakedefine HAVE_SSL_LIBRARY_INIT @HAVE_SSL_LIBRARY_INIT@
#cmakedefine HAVE_STDINT_H @HAVE_STDINT_H@
#cmakedefine HAVE_STDLIB_H @HAVE_STDLIB_H@
#cmakedefine HAVE_STRINGS_H @HAVE_STRINGS_H@
#cmakedefine HAVE_STRING_H @HAVE_STRING_H@
#cmakedefine HAVE_SYS_SELECT_H @HAVE_SYS_SELECT_H@
#cmakedefine HAVE_SYS_STAT_H @HAVE_SYS_STAT_H@
#cmakedefine HAVE_SYS_TIME_H @HAVE_SYS_TIME_H@
#cmakedefine HAVE_SYS_TYPES_H @HAVE_SYS_TYPES_H@
#cmakedefine HAVE_TIMEGM @HAVE_TIMEGM@
#cmakedefine HAVE_UNISTD_H @HAVE_UNISTD_H@
#cmakedefine HAVE_X509_CHECK_HOST @HAVE_X509_CHECK_HOST@
#cmakedefine HAVE_X509_CRL_DIGEST @HAVE_X509_CRL_DIGEST@
#cmakedefine HAVE_X509_CRL_GET0_SIGNATURE @HAVE_X509_CRL_GET0_SIGNATURE@
#cmakedefine HAVE_X509_DIGEST @HAVE_X509_DIGEST@
#cmakedefine HAVE_X509_GET0_NOTAFTER @HAVE_X509_GET0_NOTAFTER@
#cmakedefine HAVE_X509_GET0_NOTBEFORE @HAVE_X509_GET0_NOTBEFORE@
#cmakedefine HAVE_X509_GET0_SIGNATURE @HAVE_X509_GET0_SIGNATURE@
#cmakedefine HAVE_X509_STORE_CTX_GET0_CHAIN @HAVE_X509_STORE_CTX_GET0_CHAIN@
#cmakedefine HAVE_X509_VERIFY_PARAM_ID @HAVE_X509_VERIFY_PARAM_ID@
#cmakedefine O_PLMT @O_PLMT@
#cmakedefine PACKAGE_BUGREPORT @PACKAGE_BUGREPORT@
#cmakedefine PACKAGE_NAME @PACKAGE_NAME@
#cmakedefine PACKAGE_STRING @PACKAGE_STRING@
#cmakedefine PACKAGE_TARNAME @PACKAGE_TARNAME@
#cmakedefine PACKAGE_URL @PACKAGE_URL@
#cmakedefine PACKAGE_VERSION @PACKAGE_VERSION@
#cmakedefine STACK_DIRECTION @STACK_DIRECTION@
#cmakedefine STDC_HEADERS @STDC_HEADERS@
#cmakedefine SYSTEM_CACERT_FILENAME "@SYSTEM_CACERT_FILENAME@"
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@
#cmakedefine _REENTRANT @_REENTRANT@
#cmakedefine size_t @size_t@
